@@ -3,18 +3,19 @@
 ## ----------------------------------------------------------------------------
 package JSON::Assert;
 
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base 'Str';
 use JSON::Path;
 use Test::Deep::NoTest;
 
 $JSON::Path::Safe = 0;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our $VERBOSE = $ENV{JSON_ASSERT_VERBOSE} || 1;
 
 has 'error' =>
     is => "rw",
-    isa => "Str",
+    isa => Str,
     clearer => "_clear_error",
     ;
 
